# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/torchserve_client',
                'doc_host': 'https://Ankur-singh.github.io',
                'git_url': 'https://github.com/Ankur-singh/torchserve_client',
                'lib_path': 'torchserve_client'},
  'syms': { 'torchserve_client.base': { 'torchserve_client.base.BaseClient': ('base.html#baseclient', 'torchserve_client/base.py'),
                                        'torchserve_client.base.BaseClient.__init__': ( 'base.html#baseclient.__init__',
                                                                                        'torchserve_client/base.py'),
                                        'torchserve_client.base.BaseClient.__repr__': ( 'base.html#baseclient.__repr__',
                                                                                        'torchserve_client/base.py'),
                                        'torchserve_client.base.BaseClient._filter_none_values': ( 'base.html#baseclient._filter_none_values',
                                                                                                   'torchserve_client/base.py'),
                                        'torchserve_client.base.BaseClient._make_request': ( 'base.html#baseclient._make_request',
                                                                                             'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient': ( 'base.html#inferenceclient',
                                                                                    'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient.__init__': ( 'base.html#inferenceclient.__init__',
                                                                                             'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient.api_description': ( 'base.html#inferenceclient.api_description',
                                                                                                    'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient.explaination': ( 'base.html#inferenceclient.explaination',
                                                                                                 'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient.health_check': ( 'base.html#inferenceclient.health_check',
                                                                                                 'torchserve_client/base.py'),
                                        'torchserve_client.base.InferenceClient.prediction': ( 'base.html#inferenceclient.prediction',
                                                                                               'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient': ( 'base.html#managementclient',
                                                                                     'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.__init__': ( 'base.html#managementclient.__init__',
                                                                                              'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.api_description': ( 'base.html#managementclient.api_description',
                                                                                                     'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.describe_model': ( 'base.html#managementclient.describe_model',
                                                                                                    'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.list_models': ( 'base.html#managementclient.list_models',
                                                                                                 'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.register_model': ( 'base.html#managementclient.register_model',
                                                                                                    'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.scale_workers': ( 'base.html#managementclient.scale_workers',
                                                                                                   'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.set_default_version': ( 'base.html#managementclient.set_default_version',
                                                                                                         'torchserve_client/base.py'),
                                        'torchserve_client.base.ManagementClient.unregister_model': ( 'base.html#managementclient.unregister_model',
                                                                                                      'torchserve_client/base.py')},
            'torchserve_client.core': { 'torchserve_client.core.BaseClient': ('base.html#baseclient', 'torchserve_client/core.py'),
                                        'torchserve_client.core.BaseClient.__init__': ( 'base.html#baseclient.__init__',
                                                                                        'torchserve_client/core.py'),
                                        'torchserve_client.core.BaseClient.__repr__': ( 'base.html#baseclient.__repr__',
                                                                                        'torchserve_client/core.py'),
                                        'torchserve_client.core.BaseClient._filter_none_values': ( 'base.html#baseclient._filter_none_values',
                                                                                                   'torchserve_client/core.py'),
                                        'torchserve_client.core.BaseClient._make_request': ( 'base.html#baseclient._make_request',
                                                                                             'torchserve_client/core.py')},
            'torchserve_client.inference': { 'torchserve_client.inference.InferenceClient': ( 'inference.html#inferenceclient',
                                                                                              'torchserve_client/inference.py'),
                                             'torchserve_client.inference.InferenceClient.__init__': ( 'inference.html#inferenceclient.__init__',
                                                                                                       'torchserve_client/inference.py'),
                                             'torchserve_client.inference.InferenceClient.api_description': ( 'inference.html#inferenceclient.api_description',
                                                                                                              'torchserve_client/inference.py'),
                                             'torchserve_client.inference.InferenceClient.explaination': ( 'inference.html#inferenceclient.explaination',
                                                                                                           'torchserve_client/inference.py'),
                                             'torchserve_client.inference.InferenceClient.health_check': ( 'inference.html#inferenceclient.health_check',
                                                                                                           'torchserve_client/inference.py'),
                                             'torchserve_client.inference.InferenceClient.prediction': ( 'inference.html#inferenceclient.prediction',
                                                                                                         'torchserve_client/inference.py')},
            'torchserve_client.management': { 'torchserve_client.management.ManagementClient': ( 'management.html#managementclient',
                                                                                                 'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.__init__': ( 'management.html#managementclient.__init__',
                                                                                                          'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.api_description': ( 'management.html#managementclient.api_description',
                                                                                                                 'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.describe_model': ( 'management.html#managementclient.describe_model',
                                                                                                                'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.list_models': ( 'management.html#managementclient.list_models',
                                                                                                             'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.register_model': ( 'management.html#managementclient.register_model',
                                                                                                                'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.scale_workers': ( 'management.html#managementclient.scale_workers',
                                                                                                               'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.set_default_version': ( 'management.html#managementclient.set_default_version',
                                                                                                                     'torchserve_client/management.py'),
                                              'torchserve_client.management.ManagementClient.unregister_model': ( 'management.html#managementclient.unregister_model',
                                                                                                                  'torchserve_client/management.py')}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_base.ipynb.

# %% auto 0
__all__ = ['BaseClient']

# %% ../nbs/00_base.ipynb 4
import os
import requests

# %% ../nbs/00_base.ipynb 5
class BaseClient:
    def __init__(self, base_url=None):
        base_url = (
            base_url
            if base_url
            else os.environ.get("TORCHSERVE_URL", "http://localhost")
        )
        self.base_url = base_url.rstrip("/")

    def _make_request(self, method, endpoint, data=None, params=None, files=None):
        url = f"{self.base_url}{endpoint}"
        response = requests.request(method, url, json=data, params=params, files=files)
        response.raise_for_status()
        return response.json()

    def __repr__(self) -> str:
        return f"{self.__class__.__name__}(base_url={self.base_url})"

    def _filter_none_values(self, data):
        return {key: value for key, value in data.items() if value is not None}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_management.ipynb.

# %% auto 0
__all__ = ['ManagementClient']

# %% ../nbs/01_management.ipynb 2
from .base import BaseClient

# %% ../nbs/01_management.ipynb 3
class ManagementClient(BaseClient):
    def __init__(self, base_url=None, port=8081):
        super().__init__(base_url)
        self.port = port
        self.base_url = f"{self.base_url}:{self.port}"

    def register_model(
        self,
        url,
        model_name=None,
        handler=None,
        runtime=None,
        batch_size=1,
        max_batch_delay=100,
        initial_workers=0,
        synchronous=False,
        response_timeout=120,
    ):
        data = {
            "url": url,
            "model_name": model_name,
            "handler": handler,
            "runtime": runtime,
            "batch_size": batch_size,
            "max_batch_delay": max_batch_delay,
            "initial_workers": initial_workers,
            "synchronous": synchronous,
            "response_timeout": response_timeout,
        }
        data = self._filter_none_values(data)
        return self._make_request("POST", "/models", json=data)

    def scale_workers(
        self,
        model_name,
        version=None,
        min_worker=1,
        max_worker=None,
        synchronous=False,
        timeout=-1,
    ):
        if version:
            endpoint = f"/models/{model_name}/{version}"
        else:
            endpoint = f"/models/{model_name}"

        params = {
            "min_worker": min_worker,
            "max_worker": max_worker if max_worker is not None else min_worker,
            "synchronous": synchronous,
            "timeout": timeout,
        }

        return self._make_request("PUT", endpoint, data=params)

    def describe_model(self, model_name, version=None, customized=False):
        """
        Returns the model description.
        version :  is optional. if `all` return status of all version of a model. If not provided, the latest version will be returned.
        allowed
        """
        params = {}
        if customized:
            params["customized"] = customized

        if version:
            endpoint = f"/models/{model_name}/{version}"
        else:
            endpoint = f"/models/{model_name}"
        return self._make_request("GET", endpoint, params=params)

    def unregister_model(self, model_name, version=None):
        if version:
            endpoint = f"/models/{model_name}/{version}"
        else:
            endpoint = f"/models/{model_name}"

        return self._make_request("DELETE", endpoint)

    def list_models(self, limit=100, next_page_token=None):
        params = {"limit": limit, "next_page_token": next_page_token}
        params = self._filter_none_values(params)
        return self._make_request("GET", "/models", params=params)

    def api_description(self):
        return self._make_request("OPTIONS", "/")

    def set_default_version(self, model_name, version):
        endpoint = f"/models/{model_name}/{version}/set-default"
        return self._make_request("PUT", endpoint)



__version__ = "0.0.1"
# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_init.ipynb.

# %% auto 0
__all__ = ['TorchServeClient']

# %% ../nbs/01_init.ipynb 2
from .base import ManagementClient, InferenceClient

# %% ../nbs/01_init.ipynb 3
class TorchServeClient:
    def __init__(self, base_url=None, management_port=8081, inference_port=8080):
        self.management = ManagementClient(base_url, management_port)
        self.inference = InferenceClient(base_url, inference_port)

    def __repr__(self):
        url = self.management.base_url.rsplit(":", 1)[0]
        return f"TorchServeClient(base_url={url}, management_port={self.management.port}, inference_port={self.inference.port})"



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_inference.ipynb.

# %% auto 0
__all__ = ['InferenceClient']

# %% ../nbs/02_inference.ipynb 2
from .base import BaseClient

# %% ../nbs/02_inference.ipynb 3
class InferenceClient(BaseClient):
    def __init__(self, base_url=None, port=8080):
        super().__init__(base_url)
        self.port = port
        self.base_url = f"{self.base_url}:{self.port}"

    def api_description(self):
        return self._make_request("OPTIONS", "/")

    def health_check(self):
        return self._make_request("GET", "/ping")

    def prediction(self, model_name, data, version=None):
        """
        inference_data = [
            ('data', open('docs/images/dogs-before.jpg', 'rb')),
            ('data', open('docs/images/kitten_small.jpg', 'rb')),
        ]
        """
        if version:
            endpoint = f"/predictions/{model_name}/{version}"
        else:
            endpoint = f"/predictions/{model_name}"

        return self._make_request("POST", endpoint, files=data)

    def explaination(self, model_name, data):
        """
        data <string : bytes>
        """
        endpoint = f"/explanations/{model_name}"
        return self._make_request("POST", endpoint, files=data)
